@@ -137,7 +137,7 @@ int test_bkz_param_linear_pruning(ZZ_mat<ZT> &A, const int block_size, int flags
   }
 
   Strategy strategy;
-  strategy.pruning_parameters.emplace_back(Pruning::LinearPruning(block_size, block_size/2));
+  strategy.pruning_parameters.emplace_back(Pruning::LinearPruning(block_size, block_size / 2));
   strategies.emplace_back(std::move(strategy));
 
   BKZParam params(block_size, strategies);
@@ -169,7 +169,6 @@ int test_bkz_param_pruning(ZZ_mat<ZT> &A, const int block_size, int flags = BKZ_
   return status;
 }
 
-
 /**
    @brief Test BKZ for matrix stored in file pointed to by `input_filename`.
 
@@ -231,7 +230,7 @@ int test_linear_dep()
   return test_bkz_param<mpz_t>(A, 3);
 }
 
-int main(int /*argc*/, char** /*argv*/)
+int main(int /*argc*/, char ** /*argv*/)
 {
 
   int status = 0;
@@ -241,8 +240,10 @@ int main(int /*argc*/, char** /*argv*/)
   status |= test_filename<mpz_t>("lattices/dim55_in", 10, FT_DD, BKZ_SD_VARIANT | BKZ_AUTO_ABORT);
 #endif
   status |= test_filename<mpz_t>("lattices/dim55_in", 10, FT_DEFAULT, BKZ_SLD_RED);
-  status |= test_filename<mpz_t>("lattices/dim55_in", 20, FT_MPFR, BKZ_DEFAULT | BKZ_AUTO_ABORT, 128);
-  status |= test_filename<mpz_t>("lattices/dim55_in", 20, FT_MPFR, BKZ_SD_VARIANT | BKZ_AUTO_ABORT, 128);
+  status |=
+      test_filename<mpz_t>("lattices/dim55_in", 20, FT_MPFR, BKZ_DEFAULT | BKZ_AUTO_ABORT, 128);
+  status |=
+      test_filename<mpz_t>("lattices/dim55_in", 20, FT_MPFR, BKZ_SD_VARIANT | BKZ_AUTO_ABORT, 128);
   status |= test_filename<mpz_t>("lattices/dim55_in", 20, FT_MPFR, BKZ_SLD_RED, 128);
 
   status |= test_int_rel<mpz_t>(50, 1000, 10, FT_DOUBLE, BKZ_DEFAULT | BKZ_AUTO_ABORT);
